@@ -107,7 +107,7 @@ except ImportError:
                           " install ordereddict 1.1 from pypi for python2.6")
 
 __pkgname__ = 'python-crontab'
-__version__ = '2.4.2'
+__version__ = '2.5.0'
 
 ITEMREX = re.compile(r'^\s*([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)'
                      r'\s+([^@#\s]+)\s+([^\n]*?)(\s+#\s*([^\n]*)|$)')
@@ -304,7 +304,7 @@ class CronTab(object):
             self._parked_env = OrderedDict()
             if read and not item.comment and self.lines and \
               self.lines[-1] and self.lines[-1][0] == '#':
-                item.set_comment(self.lines.pop()[1:].strip())
+                item.set_comment(self.lines.pop()[1:].strip(), True)
 
             self.crons.append(item)
             self.lines.append(item)
@@ -563,14 +563,15 @@ class CronItem(object):
         self.env = OrderedVariableList(job=self)
 
         # Marker labels Ansible jobs etc
+        self.pre_comment = False
         self.marker = None
-        self.pre_comment = pre_comment
+        self.stdin = None
         self._log = None
 
         # Initalise five cron slices using static info.
         self.slices = CronSlices()
 
-        self.set_comment(comment)
+        self.set_comment(comment, pre_comment)
 
         if command:
             self.set_command(command)
@@ -598,18 +599,25 @@ class CronItem(object):
         else:
             self.cron.remove(self)
 
-    def set_command(self, cmd):
+    def set_command(self, cmd, parse_stdin=False):
         """Set the command and filter as needed"""
-        self.command = cmd.strip()
+        if parse_stdin:
+            cmd = cmd.replace('%', '\n').replace('\\\n', '%')
+            if '\n' in cmd:
+                cmd, self.stdin = cmd.split('\n', 1)
+        self.command = _unicode(cmd.strip())
 
-    def set_comment(self, cmt):
-        """Set the comment and don't filter"""
+    def set_comment(self, cmt, pre_comment=False):
+        """Set the comment and don't filter, pre_comment indicates comment appears
+        before the cron, otherwise it appears ont he same line after the command.
+        """
         if cmt and cmt[:8] == 'Ansible:':
             self.marker = 'Ansible'
-            self.pre_comment = True
-            self.comment = cmt[8:].lstrip()
-        else:
-            self.comment = cmt
+            cmt = cmt[8:].lstrip()
+            pre_comment = True
+
+        self.comment = cmt
+        self.pre_comment = pre_comment
 
     def parse(self, line):
         """Parse a cron line string and save the info as the objects."""
@@ -629,7 +637,7 @@ class CronItem(object):
         if self.cron.user is False:
             # Special flag to look for per-command user
             ret = result[0][-3].split(None, 1)
-            self.set_command(ret[-1])
+            self.set_command(ret[-1], True)
             if len(ret) == 2:
                 self.user = ret[0]
             else:
@@ -637,7 +645,7 @@ class CronItem(object):
                 self.enabled = False
                 LOG.error(str("Missing user or command in system cron line."))
         else:
-            self.set_command(result[0][-3])
+            self.set_command(result[0][-3], True)
         try:
             self.setall(*result[0][:-3])
             self.valid = True
@@ -663,13 +671,15 @@ class CronItem(object):
 
     def render(self):
         """Render this set cron-job to a string"""
-        self.command = _unicode(self.command)
+        command = _unicode(self.command).replace(u'%', u'\\%')
         user = ''
         if self.cron and self.cron.user is False:
             if not self.user:
                 raise ValueError("Job to system-cron format, no user set!")
             user = self.user + ' '
-        result = u"%s %s%s" % (unicode(self.slices), user, self.command)
+        result = u"%s %s%s" % (unicode(self.slices), user, command)
+        if self.stdin:
+            result += ' %' + self.stdin.replace('\n', '%')
         if self.comment:
             comment = self.comment = _unicode(self.comment)
             if self.marker:
@@ -677,7 +687,7 @@ class CronItem(object):
             else:
                 comment = u"# " + comment
 
-            if SYSTEMV or self.pre_comment:
+            if SYSTEMV or self.pre_comment or self.stdin:
                 result = comment + "\n" + result
             else:
                 result += ' ' + comment
